@@ -1,4 +1,9 @@
 #include "../main.f"
+#include "Zepcondc.h"
+#if defined (INTINFO)
+#include "epUI.f"
+#endif
+
 c        **************************************************************
 c        *
 c        * ephook:  collection of subroutines which should be managed by
