@@ -1,14 +1,13 @@
       implicit none
 #include "Zmedia.h"
 #include "Zmass.h"
-!
-!          test compton
-! 
-       type(epmedia):: media
-      integer i, io, imax, icon
+c
+c          test compton
+c 
+      record /epmedia/media
+      integer i, io, imax
       real*8 Ee, prob, Eg, cosg, cose, Egp, path
-      character*120 file
-      character(len=8):: name
+      character*20 file
 
       io = 10
       imax = 50000
@@ -18,14 +17,13 @@
 
 
       call  cerrorMsg(
-     * "Enter gamma energy, events(50000) and media name"//
-     * "BGO",  1)
-
-      read(*, *) Eg, imax, name
-      call cerrorMsg(name,  1)
-      file = '$EPICSTOP/Data/BaseM/'//trim(name)
-      call copenf(io, file, icon)
+     * "Enter gamma energy, events(50000) and file path"//
+     * "('../../Data/BaseM/BGO')",  1)
+      file = '../../Data/BaseM/BGO'
+      read(*, *) Eg, imax, file
+      call cerrorMsg(file,  1)
 
+      open(io, file=file, action='read')
       call epReadMTbl(io, media)
       close(io)
       call epGetEffZA(media)
@@ -35,7 +33,7 @@
       do i = 1,  imax
          call epcompp(media, Eg, prob, path)
          call epcompea(Eg, Egp, Ee, cosg, cose)
-         write(*,'(1p, 6g13.4)') prob, Egp, Ee, cosg, cose, path
+         write(*,*) sngl(prob), sngl(Egp),
+     *     sngl(Ee), sngl(cosg), sngl(cose), sngl(path)
       enddo
       end
-
