@@ -1,6 +1,6 @@
         integer maxn
-	parameter ( maxn = 20000 )
-        real*8  wzmin, wzmax, trackl
+	parameter ( maxn = 50000 )
+        real*8  wzmin, wzmax, trackl, LabEquivE
 	real*8  ke(maxn)
 	integer indx(maxn)
         integer nevent
@@ -10,18 +10,20 @@
         integer  inpfileno, xyz
         real*8   pjpx, pjpy, pjpz
 	real*8   tgpx, tgpy, tgpz
-        real  xpos, ypos, zpos  
+        character(8):: targetName
+c        real  xpos, ypos, zpos  
+        real(4)::xpos(3)     
         integer pjmnum, tgmnum  ! proj. target mass number
         record /ptcl/ pj, tg, plab
         common /Zotherc/ pj, tg, plab,  ke, wzmin, wzmax, 
      *    trackl, pjpx, pjpy, pjpz, tgpx, tgpy, tgpz,
-     *    xpos, ypos, zpos,  
+c     *    xpos, ypos, zpos,  
+     *    xpos, LabEquivE,
      *    indx, nevent, outzero,
      *    pjmnum, tgmnum, inpfileno, xyz,
      *	  pjcode, pjsub, pjchg,
      *	  tgcode, tgsub, tgchg
-
-	  
+        common /ZothercCha/ targetName
 
 
 
