@@ -423,7 +423,7 @@ c     ********************
          do j = 1, noOfMedia
             if(seledMedia(i) .eq. matdef(j)) then
                byMedia = .true.
-               goto 10
+               exit
             endif
          enddo
       enddo
@@ -713,6 +713,7 @@ c         epexec for subd
       real*8 r
       data showusage/.true./
       save showusage
+      integer uscl
 
 c      call mediaCount(cmp, matdef, noOfMedia, compnToMn)
       call mediaCount(cmp, ncmp, matdef, noOfMedia)
@@ -733,12 +734,14 @@ c           i is being drawn
      *        r*cos(pamax*Torad), r*cos(pamin*Torad), pv, nv)
          elseif(cmp(i).struc(1:4) .eq. 'pipe') then
             call epdrawPipe(cmp(i), pv, nv)
-         elseif(cmp(i).struc(1:5) .eq. 'prism') then
+         elseif(cmp(i).struc .eq. 'prism' .or.
+     *          cmp(i).struc(1:6) .eq. 'prism_' ) then
             call epdrawPrism(cmp(i),  pv, nv)
          elseif(cmp(i).struc(1:4) .eq. 'new-' ) then
             call epDrawNew(cmp(i), pv, nv)
          else
-            tempph = epparaphrase(cmp(i).struc(1:8))
+            call epseeUnderScore( cmp(i).struc, uscl)
+            tempph = epparaphrase(cmp(i).struc(1:uscl))
             if(tempph(1:4) .eq. 'new-' ) then
                call epDrawNew(cmp(i), pv, nv)
             else
@@ -1233,7 +1236,7 @@ c         howcyl = 00
          pamin = 10.
          pamax = 170.
          drawall = .true.
-         clevelmax = 4
+         clevelmax = 6
          clevelmin = 0
          call epgetCond         ! get old conditions, if any 
          first = .false.
@@ -1482,10 +1485,16 @@ c    *********************
 #include "Zcnfig.h"
 #include "ZepDraw.h"
       integer i, j, w
+      record /epPos/ org
+      record /ep3Vec/ abc
 
 c         read config file
       call eprcnf(configFile)
 
+      call epqcnf(org, abc)
+      write(0, *) 'Bounding box of the world'
+      write(0, '(a,1p,3g15.7)') ' origing=', org
+      write(0, '(a,1p,3g15.7)') ' box x y z length=',abc
 
       NumComp = Det.nct
       NumWorld = Det.nworld
@@ -1504,7 +1513,8 @@ c         read config file
             w = 10
          elseif(Det.cmp(i).struc(1:4) .eq. 'pipe') then
             w = 20
-         elseif(Det.cmp(i).struc(1:5) .eq. 'prism') then
+         elseif(Det.cmp(i).struc .eq. 'prism' .or.
+     *          Det.cmp(i).struc(1:6) .eq. 'prism_') then
             w = 2
          else
             w = 10
