@@ -14,10 +14,8 @@ c
       integer uscl
 
       call epseeUnderScore(comp.struc, uscl)
-      if(comp.struc(1:uscl) .eq. 'cone') then
-         call epDraw_cone(comp, p, n)
-      elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
-         call epDraw_fpolygon(comp, p, n)
+      if(comp.struc(1:uscl) .eq. 'torus') then
+         call epDraw_torus(comp, p, n)
 c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epDraw_%2(comp, p, n)
       else
