@@ -1,5 +1,5 @@
       block data  epblksepi
-!
+c
 #include  "ZsepManager.h"
       data  IoCont/12/, Ir1/111, 89072411/
       data  StackDiskFileNo/13/
