@@ -1,13 +1,12 @@
 #include "ZepMaxdef.h"
 #include "ZepPos.h"
-
       integer maxvtx ! max number of vertex for one component
       real*8 gpsep   ! to show separater
       integer nvccl  ! a circle is approximated  by regular polygon of
                      ! nvccl vertexes.
       integer nvsph  ! to draw a sphere, polar angle is devided into
                      !   nvsph.
-!      integer cut    !   0--> no cut in cyl, sphere
+c      integer cut    !   0--> no cut in cyl, sphere
                      !   1--> cut along longitude in  cyl and sphere
                      !   2--> cut around the poles in  sphere
                      !   3--> cut around the poles and along 
@@ -60,12 +59,11 @@
       integer maxmat
       parameter (maxmat = 40)
       integer mcolor(maxmat)
-      integer NoOfCompsEachMedia(maxmat)
       character*6 collist(maxmat)
       character*6 origcol(10)
       integer  maxspecifiable
       parameter (maxspecifiable = 100)
-      integer*4 compnumb(maxspecifiable),
+      integer*2 compnumb(maxspecifiable),
      *    mamordaught(maxspecifiable)
       character*8  matdef(maxmat)
       integer noOfMedia
@@ -92,9 +90,9 @@
       integer maxmenu, nselstruc, nselMedia 
       integer subdnumber, NumComp,  NumWorld
       parameter (maxmenu=15)
-      integer*4  draworhide(maxcomp)
+      integer*2  draworhide(maxcomp)
       character*320 mlist, sellist
-       type(epPos)::  pv(maxvtx)
+      record /epPos/ pv(maxvtx)
       integer ndraw,  drawcomp(maxcomp)
       integer nstruc  ! no of defined structures in the config
       character*320 struclist, selstruclist
@@ -111,8 +109,8 @@
      * drawcomp, byContain, byStruc, byMedia, byNumb,
      * compnumb, mamordaught, ahow, ahowcyl,
      * abyContain, abyMedia, abyStruc, Ndflt, Reverse,
-     * confOrtrk, maxlevel, clevelmin, clevelmax,
-     * NoOfCompsEachMedia
+     * confOrtrk, maxlevel, clevelmin, clevelmax
+ 
       common /zdawcc/CondID,  configFile, msg, mlist, sellist,
      *  matdef, fn, struclist, selstruclist, strucarray,
      *  selstrucarray, seledMedia, origcol, collist,
