@@ -2,7 +2,7 @@
       implicit none
 #include "ZepManager.h"
 #include "Zmedia.h"
-       type(epmedia)::  media
+      record /epmedia/ media
 
       character*8 name   !   media name.
       integer n            !-->size  output.  number of rows of xcomtab
@@ -14,7 +14,7 @@
       character*100 mdpath
       
       icon = -1
-      name = media%name
+      name = media.name
 
       do i = 1, MaxMediaDir
          if( klena(MediaDir(i)) .gt. 0 ) then
@@ -38,47 +38,46 @@
             n = 0
             do while(.true.)
                read(iowk, *, end=100)
-     *            ( media%xcom%tab(k,n+1), k = 1, 8)
+     *            ( media.xcom.tab(k,n+1), k = 1, 8)
                n = n + 1
             enddo
  100        continue
             close(iowk)
 
-            media%xcom%size = n
-!              count shell energy levels
+            media.xcom.size = n
+c              count shell energy levels
             ns = 0
             do is = 1, n-1
-               if( media%xcom%tab(1,is) .eq.
-     *             media%xcom%tab(1,is+1) ) then 
+               if( media.xcom.tab(1,is) .eq.
+     *             media.xcom.tab(1,is+1) ) then 
                   ns = ns +1
                   if(ns .gt. maxNoOfShells) then
                      write(0,*) ' media=',name, ' has ',
      *                 ' shells > ', maxNoOfShells
                      stop 1235
                   endif
-                  media%pe%shellE(ns)=media%xcom%tab(1,is)
+                  media.pe.shellE(ns)=media.xcom.tab(1,is)
                endif
             enddo
 
-            media%pe%noOfShells=ns
+            media.pe.noOfShells=ns
 
-!             we use log table.
+c             we use log table.
             icon = 0
             do k = 1, n
                do j= 1, 8
-                  if( media%xcom%tab(j, k) .eq. 0.) then
-!!!                    media%xcom%tab(j,k) = -100   ! too small.  better  to use next 2020/06/23
-                     media%xcom%tab(j,k) = -46.0
+                  if( media.xcom.tab(j, k) .eq. 0.) then
+                     media.xcom.tab(j,k) = -100
                   else
-                     media%xcom%tab(j,k) = log( media%xcom%tab(j,k) )
+                     media.xcom.tab(j,k) = log( media.xcom.tab(j,k) )
                   endif
                enddo
             enddo
-!           *****
+c           *****
             write(0,*) mdpath(1:klena(mdpath)),
      *       ' has been read, no of shells=',ns
             exit
-!           ****
+c           ****
          endif
       enddo
 
