@@ -40,18 +40,6 @@ module SampMolReducedA
   integer:: funcno    ! selectef function number 0, 1, or 2  for sampling
   real(8):: add   ! working var. to  sum up quantities
   real(8):: B2   ! B^2
-  real(8),save:: sbMin=1.5d0 ! in epSampMol.f, if sb < sbmin
-  !  Moliere theory is not used.
-  !  1.5 is old default and gives almos the same resulst when
-  !  El_hin modle is used in many applications. However, in some
-  ! case, the lateral spread becomes bit wider than the El_hin case
-  ! (which should be better).  To make usual Moliere treatment
-  ! coinside with the El_hin case, make this value laerger.
-  ! For CALET case, 7.4d0 is better.   (But the longitudinal
-  ! development little bit differ from El_hin case.  If 6.8 is
-  ! used, longitudinal dev. coinsides with El_hin but lateral spread
-  ! beomes bit wider).
-  !
   real(8):: Pos, Neg, Tot
   real(8):: eff  ! used for sampling  when some of f1,f2 becoem negative
                  ! see later
@@ -79,16 +67,13 @@ module SampMolReducedA
 
   contains
 
-  subroutine epSampMolReducedA(B, Mol, thetasq, icon)
+  subroutine epSampMolReducedA(B, thetasq, icon)
     use modcsampAF
     implicit none
     real(8),intent(in)::B  ! Moliere's B 
-    integer,intent(in)::Mol ! same as Moliere
     real(8),intent(out)::thetasq ! sample reduced angle square (x)
                ! tetasq = x ; teta= sqrt(tetasq*B*xc2)
     integer,intent(out)::icon  ! =0, ok, =1, not ok-
-      ! if Mol=4 and f(0) is selected, 1 is set so later
-      ! Gaussian sampling shoul be tried. 
     real(8):: u, ans
     real(8)::x   !  thetasq
     logical,save::first=.true.
@@ -150,12 +135,6 @@ module SampMolReducedA
        enddo
 !    funcno function is used 
        if(funcno == 0 ) then
-!!!!!!           v9.170
-          if(Mol == 4) then
-             icon = 1
-             return
-          endif
-!!!!!
         ! 2exp(-x) dx  in region.   solv
         ! (exp(-x1) -exp(-x2))u = (exp(-x1) - exp(-x))
           x1 = real( xr(region))
