@@ -1,63 +1,29 @@
       subroutine eppush(aTrack)
       implicit none
-!#include  "ZepTrack.h"
-#include  "ZepTrackv.h"
+#include  "ZepTrack.h"
 #include  "ZepStack.h"
 #include  "ZsepManager.h"
-#include  "Zcode.h"
+
       
-       type(epTrack)::  aTrack ! input ptcl to be stacked
+      record /epTrack/ aTrack
       integer:: size
       integer i
       character(len=192)::stackdiskpath
 
-       type(epTrack)::  bTrack ! copy of aTrack
-#if defined (jaxa) || (jaxaflat) 
-       type(epTrack):: dummyTrack(2)   ! to get size
-#endif
-
-      bTrack = aTrack
-      if( Making1ry == 1 ) then
-         ! now 1ry is being stacked
-         Total1ryE =Total1ryE + bTrack%p%fm%p(4) -bTrack%p%mass
-         bTrack%inciflag = 1
-      else
-         if( Move%Track%inciflag == 0 )  then
-            bTrack%inciflag = 0 ! bulk of cases come here
-!                  so separated from  the next subrotuine
-         else
-            call epManageInciflag(aTrack, bTrack) ! in epSetupV1ry
-         endif
-      endif
-
       if(Stack_pos .ge. MaxStackSize) then
          if( DdiskNo == 0 ) then
            ! open direct access file in binary 
             DdiskNo = StackDiskFileNo
-#if defined (jaxa) || (jaxaflat) 
-!  this is not used by  ifort;  loc is non standard but
-!  loc seems to be usable by ifort too. 
-            size = loc( dummyTrack(2)) -loc( dummyTrack(1))
-#else
-            size = sizeof(bTrack)      ! in bytes      
-#endif
+            size= sizeof(aTrack) 
             if(StackDiskFile == "scratch" ) then
                open(DdiskNo,  status="scratch",
-     *              form="unformatted", access="direct",
-#if defined (Solaris) || (jaxa) || (jaxaflat) || (MacGfort) || (LinuxGfort)
-     *           RECL=size)   
-#else
+     *           form="unformatted", access="direct",
      *           recordsize=size)   
-#endif
             else
                call cgetfname(StackDiskFile, stackdiskpath)
                open(DdiskNo,  file=stackdiskpath,
      *           form="unformatted", access="direct",
-#if defined Solaris || (jaxa) || (jaxaflat) || (MacGfort) || (LinuxGfort)
-     *           RECL=size)   
-#else
      *           recordsize=size)   
-#endif
             endif
             write(0,*) 'memory stack area=',MaxStackSize
             write(0,*) ' is not enought so that direct '
@@ -77,20 +43,18 @@
             endif
          endif
          Diskpos = Diskpos + 1
-!//////////////////////
-!         if( bTrack.cn == 0 ) then
-!            write(0,*) ' push cn=0. code =',bTrack.p.code
-!            write(0,*) ' pos =',bTrack.pos.x,bTrack.pos.y,bTrack.pos.z
-!         endif
-!///////////////////
-         write(DdiskNo, rec=Diskpos) bTrack
+c//////////////////////
+c         if( aTrack.cn == 0 ) then
+c            write(0,*) ' push cn=0. code =',aTrack.p.code
+c            write(0,*) ' pos =',aTrack.pos.x,aTrack.pos.y,aTrack.pos.z
+c         endif
+c///////////////////
+         write(DdiskNo, rec=Diskpos) aTrack
       else
          Stack_pos = Stack_pos + 1
-         Stack(Stack_pos) = bTrack
+         Stack(Stack_pos) = aTrack
       endif
       end  subroutine eppush
-
-
    !       ************************
    !        put 1ptcl in the stack area (for unknown cn)
    !       if stack overflows, disk is automatically used.
@@ -101,36 +65,36 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 
-       type(epTrack)::  aTrack   ! input. 
+      record /epTrack/ aTrack   ! input. 
 
-!                 find component # for pos (world coord.)
-!              and  set it in aTrack.cn
-      call eppos2cn(0,  aTrack,  aTrack%cn)
-!         convert pos/w into  l.c
-      if(aTrack%cn .le. Det%nct ) then
+c                 find component # for pos (world coord.)
+c              and  set it in aTrack.cn
+      call eppos2cn(0,  aTrack,  aTrack.cn)
+c         convert pos/w into  l.c
+      if(aTrack.cn .le. Det.nct ) then
 
-         call epw2l(aTrack%cn, aTrack%pos, aTrack%pos)
-!c           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
-         call epw2ldm(aTrack%cn, aTrack%w,  aTrack%w, aTrack%p)
+         call epw2l(aTrack.cn, aTrack.pos, aTrack.pos)
+cc           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
+         call epw2ldm(aTrack.cn, aTrack.w,  aTrack.w, aTrack.p)
          call eppush(aTrack)
       else
-         write(0,*) ' current comp. #=',aTrack%cn,
-     *        ' total comp.#=', Det%nct
+         write(0,*) ' current comp. #=',aTrack.cn,
+     *        ' total comp.#=', Det.nct
          write(0,*) ' epputTrack: ptcl is not in detector'
          stop
       endif
       end subroutine epputTrack
-!       ************************
-!         put 1 ptcl in the stack disk (for unknown cn)
-!     
+c       ************************
+c         put 1 ptcl in the stack disk (for unknown cn)
+c     
       subroutine epputTrk2(io, aTrack)
       implicit none
 #include "ZepTrack.h"
 
       integer io               !  disk file number to stack the track
-       type(epTrack)::  aTrack   ! input. 
-!                 find component # for pos (world coord.)
-!              and  set it in aTrack.cn
+      record /epTrack/ aTrack   ! input. 
+c                 find component # for pos (world coord.)
+c              and  set it in aTrack.cn
       write(0,*) " You called  epputTrk2 "
       write(0,*) " please use 'call epputTrack(aTrack)' "
       write(0,*) " you need not open the disk "
@@ -139,10 +103,10 @@
       write(0,*) " by StackDiskFileNo (default is 13) "
       stop
       end subroutine epputTrk2
-!      ******************* 
+c      ******************* 
       subroutine epempty
       implicit none
-!             clear the stack
+c             clear the stack
 #include  "ZepTrack.h"
 #include  "ZepStack.h"
       logical,save::first=.true.
@@ -155,22 +119,22 @@
       endif
 
       end  subroutine epempty
-!     ******************************
+c     ******************************
       subroutine eppop(aTrack, icon)
       implicit none
-!             get 1 particle from the stack area
-!              icon=0:  1 ptcl gotten
-!                  -1:  no more ptcl
+c             get 1 particle from the stack area
+c              icon=0:  1 ptcl gotten
+c                  -1:  no more ptcl
 #include  "ZepTrackv.h"
 #include  "ZepTrackp.h"
 #include  "ZepStack.h"       
-!
-       type(epTrack)::  aTrack
+c
+       record /epTrack/ aTrack
        integer::icon
-!/////////////
-!       integer onlyonce
-!       common /dddebug/ onlyonce
-!//////////
+c/////////////
+c       integer onlyonce
+c       common /dddebug/ onlyonce
+c//////////
 
        icon=0
        do while( .true. )
@@ -178,22 +142,22 @@
              read(DdiskNo, rec=Diskpos ) aTrack
              Diskpos = Diskpos - 1
           elseif(Stack_pos > 0)  then
-!                vectors are in local.c
+c                vectors are in local.c
              aTrack = Stack(Stack_pos)     
              Stack_pos = Stack_pos - 1
           else
              icon  = -1
              exit
           endif
-!                make cosmos ptcl; e may not be informed. g may  not be,
-!                                  if IncGp=0.
-          if( aTrack%p%code > 0 ) then !   <<<<>>>> light
-             call ep2cosPtcl(aTrack%p)
+c                make cosmos ptcl; e may not be informed. g may  not be,
+c                                  if IncGp=0.
+          if( aTrack.p.code > 0 ) then !   <<<<>>>> light
+             call ep2cosPtcl(aTrack.p)
           endif                 !   <<<<>>>> light
 
-!              do business when a new component appear
+c              do business when a new component appear
           call epnewComp(aTrack)
-          if( Light > 0 .and. aTrack%p%code < 0 ) then
+          if( Light > 0 .and. aTrack.p.code < 0 ) then
                 ! special routine for light related ptlcs.
              call epLightAtPop(aTrack, icon)
              if( icon /=  0 ) cycle
@@ -203,17 +167,17 @@
           exit
        enddo
        end  subroutine eppop
-!       *************************
+c       *************************
       subroutine epqsTrack(n, sTrack)
       implicit none
 #include  "ZepTrack.h"
       integer,intent(in):: n  ! stack pos
-       type(epTrack)::  sTrack   ! output
+      record /epTrack/ sTrack   ! output
 
       integer:: icon
       call epgetTrack(n, sTrack, icon)
       if(icon /= 0 ) then
-         sTrack%p%fm%p(4) = 0.
+         sTrack.p.fm.p(4) = 0.
       endif
       end subroutine epqsTrack
 
@@ -225,9 +189,9 @@
 #include  "ZepTrack.h"
 #include  "ZepStack.h"
 
-!
+c
       integer n                 ! input. track in n-th stack position
-       type(epTrack)::  aTrack   ! output
+      record /epTrack/ aTrack   ! output
       integer icon              ! output. 0--> ok
                                  !        non 0--> no n-th stack
       if(n >= 1 .and. n <= Stack_pos) then                   
@@ -248,17 +212,17 @@
          icon  = 1
       endif
       end subroutine epgetTrack
-!       *************************
+c       *************************
       subroutine epretTrack(n, aTrack, icon)
       implicit none
-!            inverse  of epgetTrack
-!            returns aTrack  to the n-th pos in the stack
-!                 
+c            inverse  of epgetTrack
+c            returns aTrack  to the n-th pos in the stack
+c                 
 #include  "ZepTrack.h"
 #include  "ZepStack.h"
-!
+c
       integer n                 ! input. track in n-th stack position
-       type(epTrack)::  aTrack   ! input. 
+      record /epTrack/ aTrack   ! input. 
       integer icon              ! output.  0--> ok
 !          1--> n is outside of the region
       if(n >=  1 .and. n <= Stack_pos) then                   
