@@ -24,9 +24,8 @@ c
       integer i, cnxx, j, cnx, jcon
       record /epPos/postemp
       record /epDirec/ dirtemp
-
-
 c          present comp, boundary
+
       call epbndry2(Cn, el, jcon)
       if(jcon .ne. 0) then
 c               No boundary found in the  present comp. strange.
@@ -36,7 +35,6 @@ c         etc and continue the execution.
 c         However, this also happens if a wrong incident direcion is given,
 c         too or by some unkown reason. So we count the occurence / event
 c         issue messages.
-
          Bndryerr = Bndryerr + 1    ! count it
          call eppos2cn(Cn, cTrack, cnxx)
          if(cnxx .ge. Det.nct) then
@@ -134,61 +132,3 @@ c))))))))))
          icon = 0
       endif
       end
-      subroutine epbndry2(cnx, el, icon)
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-c
-c          get the length to the nearest crossing point of cTrack
-c          and the specified component
-c
-        integer cnx   ! input. cnx-th component is examined
-        real*8  el    ! output. length to the boundary of the cnx-th  comp
-                      !         from cTrack.
-        integer icon  ! output. 0, x,y,z is inside
-                      !         1  outside,
-                      !        -1  no Xssing
-
-        record /epPos/ posw, posl
-        record /epDirec/ dirw, dirl
-        integer:: uscl
-
-        character*80 msg
-        character*8  epparaphrase, tempph
-
-        if(Cn .eq. cnx) then
-c            no need to conv. to local.coor.
-           posl =cTrack.pos
-           dirl =cTrack.w 
-        else
-           call epl2w(Cn, cTrack.pos, posw)
-           call epw2l(cnx, posw, posl)
-           call epl2wd(Cn, cTrack.w, dirw)
-           call epw2ld(cnx, dirw, dirl)
-        endif
-
-        if(Det.cmp(cnx).struc(1:3) .eq. 'box') then
-           call epbbox(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:3) .eq. 'cyl') then
-           call epbcyl(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:4) .eq. 'pipe') then
-           call epbpip(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:5) .eq. 'prism') then
-           call epbprs(Det.cmp(cnx), posl, dirl,  el, icon)
-        elseif(Det.cmp(cnx).struc(1:6) .eq. 'sphere') then
-           call epbsph(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:4) .eq. 'new-') then
-           call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
-        else
-           call epseeUnderScore(Det.cmp(cnx).struc, uscl)
-           tempph = epparaphrase(Det.cmp(cnx).struc(1:uscl))
-           if(tempph(1:4) .eq. 'new-') then
-              call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
-           else
-c                   
-              write(msg, *) ' strange structure=',
-     *             Det.cmp(cnx).struc
-              call cerrorMsg(msg, 0)
-           endif
-        endif
-        end
