@@ -43,6 +43,10 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, EminElec)
                elseif( vname .eq. 'EminGamma') then
                   call arprmr(vvalue, EminGamma)
+               elseif( vname .eq. 'AutoEmin') then
+                  call arprmi(vvalue, AutoEmin)
+               elseif( vname .eq. 'ModifyFile') then
+                  call arprmc(vvalue, ModifyFile)
                elseif( vname .eq. 'EminH') then
                   call arprmr(vvalue, EminH)
                elseif( vname .eq. 'Es' ) then
@@ -56,13 +60,13 @@ c            read baisc parameters; find separater
                elseif( vname .eq. 'Knckon' ) then
                   call arprml(vvalue, Knckon)
                elseif( vname .eq. 'Molier' ) then
-                  call arprmc(vvalue, msg)  ! to cope with v9.10 
-                  if( msg == '1' .or. msg == '2') then
-                     Moliere = .true.
-                  elseif( msg == '0' ) then
-                     Moliere = .false.
+                  call arprmc(vvalue, msg)
+                  if( msg == 't' .or. msg == 'T') then
+                     Moliere = 1
+                  elseif( msg == 'f' .or. msg == 'F' ) then
+                     Moliere = 0
                   else
-                     call arprml(vvalue, Moliere)
+                     call arprmi(vvalue, Moliere)
                   endif
                elseif( vname .eq. 'Photo') then
                   call arprml(vvalue, Photo)
@@ -127,23 +131,24 @@ c            read baisc parameters; find separater
                   endif
                   call arprmc(vvalue, MediaDir(mediadirc))
                elseif( vname .eq. 'TraceDir') then
-!                      
-                  write(0,*)
-     *               ' TraceDir should be specified in sepicsfile'
-!                  call  arprmc(vvalue, TraceDir)
+                  call  arprmc(vvalue, TraceDir)
                elseif( vname .eq. 'Excom1' ) then
                   call arprmr(vvalue, Excom1) 
                elseif( vname .eq. 'Excom2' ) then
                   call arprmr(vvalue, Excom2) 
                elseif( vname .eq. 'LPMeffect' ) then
                   call arprml(vvalue, LPMeffect)                 
+               elseif( vname == "StoppingPw" ) then
+                  call arprmi(vvalue, StoppingPw)
+               elseif( vname == "SrimEmax" ) then
+                  call arprmr(vvalue, SrimEmax)
                elseif( vname == "PhitsXs" ) then
                   call arprmi(vvalue, PhitsXs)
                elseif( vname == "JamXs" ) then
                   call arprmi(vvalue, JamXs)
                else
                   write(0,*) ' epicsfile parameter: ', vname,
-     *                 ' is not usable in this version; sorry'
+     *                 ' is undefined '
                   if( vname .eq. "epHooks" ) then
                      write(0,*)
      *                "Now, this must be placed in sepicsfile"
@@ -168,13 +173,15 @@ c      *************
             call awprmr(io,'ElowerBndPair ', ElowerBndPair)
             call awprmr(io,'EminElec', EminElec)
             call awprmr(io,'EminGamma', EminGamma)
+            call awprmi(io,'AutoEmin', AutoEmin)
+            call awprmc(io, 'ModifyFile', ModifyFile)
             call awprmr(io,'EminH', EminH)
             call awprmr(io,'Es   ', Escat)
             call awprmr(io,'EupperBndCS ', EupperBndCS)
             call awprmi(io,'IncGp', IncGp)
             call awprmi(io,'IoTrace', IoTrace)
             call awprml(io,'Knckon', Knckon)
-            call awprml(io,'Molier', Moliere)
+            call awprmi(io,'Molier', Moliere)
             call awprml(io,'Photo', Photo)
             call awprmr(io,'RecoilKeMin', RecoilKEmin)
             call awprmr(io,'Tcoef' , Tcoef)
@@ -195,6 +202,7 @@ c      *************
             call awprmr(io, 'Excom1', Excom1)
             call awprmr(io, 'Excom2', Excom2)
             call awprml(io, 'LPMeffect', LPMeffect)
+            call awprmi(io, 'StoppingPw', StoppingPw)
             call awprmi(io, 'PhitsXs', PhitsXs)
             call awprmi(io, 'JamXx', JamXs)
             do i = 1, MaxMediaDir
@@ -206,14 +214,16 @@ c      *************
 c      ************
        subroutine  epcmp1
 c      ************
+       use epModify
        implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
+#include "ZepManager.h"
 #include "Zmass.h"
 c             compute something using basic parameters
 c
        if(ALateCor .eq. 2 .or.
-     *        ( ALateCor .eq. 1 .and. .not. Moliere)) then
+     *        ( ALateCor .eq. 1 .and.  Moliere == 0)) then
 c          angular latelaral correlation will be taken at
 c          multiple scattering. use standard trucation
           Tcoefx = Tcoef
@@ -225,17 +235,27 @@ c          truncation length shorter
           Tminx = Tmin/2
        endif
        if(KEmin .eq. 0.) then
-          KEmin = EminElec - masele
+          KEmin = max(EminElec - masele, 20.d-3)  ! 20 MeV
        endif
        if( EminH == 0. ) then
-          EminH = max( KEmin, 5.d-3) 
+          EminH = max( KEmin, 20.d-3)   ! for nutron
        endif
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
        endif
+c           save;  to be used in epModify;  in GeV
+       EminGsave = EminGamma
+       EminEsave = EminElec
+       RecoilEsave = RecoilKEmin
+       KEminsave = KEmin 
+       Enminsave = EminH 
+       ElecMass = masele  
 
-!        inform something to Cosmos
+
+       if( ModifyFile /= " " ) then  ! special modification requested
+          call epfixModifier(ModifyFile)
+       endif
+c        inform something to Cosmos
        call epInfoPhotoP( IncGp )
        call epInfoPhitsJamXs( PhitsXs, JamXs )
-
        end
